skalibs: the unixonacid library interface
Keywords: skalibs library unixonacid libunixonacid unixonacid.h

libskarnet
skalibs
Software
skarnet.org

# The `unixonacid` library interface

`libunixonacid` provides higher-level interfaces to Unix concepts such as the filesystem - for instance, it provides a way to access several files atomically, be it for reading or for writing - or interprocess communication.

## Compiling

- Use `#include <skalibs/unixonacid.h>`

## Programming

The `skalibs/unixonacid.h` header is actually a concatenation of other headers, every one of each declaring related structures, macros and functions.

- skalibs/unix-transactional.h: transactional filesystem operations
- skalibs/unix-timed.h: timed synchronous IPC or network operations
- skalibs/unixmessage.h: safe asynchronous and synchronous message transmission between processes via Unix sockets, including fd-passing
- skalibs/kolbak.h: simple callback management for asynchronous message transmission
- skalibs/skaclient.h: higher-level client-server interface using messages